@@ -1,5 +1,5 @@
 use {
-    crate::{state::*, errors::*},
+    crate::{state::*, errors::ErrorCode},
     anchor_lang::{prelude::*},
     cardinal_token_manager::{program::CardinalTokenManager, state::{TokenManager}}, 
 };
@@ -9,7 +9,7 @@ pub struct InvalidateCtx<'info> {
     #[account(mut)]
     token_manager: Box<Account<'info, TokenManager>>,
 
-    #[account(mut, constraint = use_invalidator.usages >= use_invalidator.max_usages.unwrap() @ ErrorCode::InsufficientUsages)]
+    #[account(mut, constraint = use_invalidator.usages >= use_invalidator.total_usages.unwrap() @ ErrorCode::InsufficientUsages)]
     use_invalidator: Box<Account<'info, UseInvalidator>>,
 
     #[account(mut)]
@@ -17,20 +17,22 @@ pub struct InvalidateCtx<'info> {
 
     // programs
     cardinal_token_manager: Program<'info, CardinalTokenManager>,
+    /// CHECK: This is not dangerous because we don't read or write from this account
     token_program: UncheckedAccount<'info>,
 
     // cpi accounts
+    /// CHECK: This is not dangerous because we don't read or write from this account
     #[account(mut)]
     token_manager_token_account: UncheckedAccount<'info>,
+    /// CHECK: This is not dangerous because we don't read or write from this account
     #[account(mut)]
     mint: UncheckedAccount<'info>,
+    /// CHECK: This is not dangerous because we don't read or write from this account
     #[account(mut)]
     recipient_token_account: UncheckedAccount<'info>,
-    #[account(mut)]
-    issuer_token_account: UncheckedAccount<'info>,
 }
 
-pub fn handler<'key, 'accounts, 'remaining, 'info>(ctx: Context<'key, 'accounts, 'remaining, 'info, InvalidateCtx<'info>>) -> ProgramResult {
+pub fn handler<'key, 'accounts, 'remaining, 'info>(ctx: Context<'key, 'accounts, 'remaining, 'info, InvalidateCtx<'info>>) -> Result<()> {
     let token_manager_key = ctx.accounts.token_manager.key();
     let use_invalidator_seeds = &[USE_INVALIDATOR_SEED.as_bytes(), token_manager_key.as_ref(), &[ctx.accounts.use_invalidator.bump]];
     let use_invalidator_signer = &[&use_invalidator_seeds[..]];
@@ -41,8 +43,8 @@ pub fn handler<'key, 'accounts, 'remaining, 'info>(ctx: Context<'key, 'accounts,
         token_manager_token_account: ctx.accounts.token_manager_token_account.to_account_info(),
         mint: ctx.accounts.mint.to_account_info(),
         recipient_token_account: ctx.accounts.recipient_token_account.to_account_info(),
-        issuer_token_account: ctx.accounts.issuer_token_account.to_account_info(),
         invalidator: ctx.accounts.use_invalidator.to_account_info(),
+        collector: ctx.accounts.invalidator.to_account_info(),
         token_program: ctx.accounts.token_program.to_account_info(),
     };
     let cpi_ctx = CpiContext::new(ctx.accounts.cardinal_token_manager.to_account_info(), cpi_accounts)
