@@ -1,9 +1,11 @@
 pub mod init;
 pub mod increment_usages;
 pub mod invalidate;
+pub mod extend_usages;
 pub mod close;
 
 pub use init::*;
 pub use increment_usages::*;
 pub use invalidate::*;
+pub use extend_usages::*;
 pub use close::*;
